[farsight2/master] We need a least one codec thats valid for sending

Olivier Crête olivier.crete at collabora.co.uk
Tue Dec 23 15:25:48 PST 2008


---
 gst/fsrtpconference/fs-rtp-codec-negotiation.c |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/gst/fsrtpconference/fs-rtp-codec-negotiation.c b/gst/fsrtpconference/fs-rtp-codec-negotiation.c
index 3c35186..c2f2051 100644
--- a/gst/fsrtpconference/fs-rtp-codec-negotiation.c
+++ b/gst/fsrtpconference/fs-rtp-codec-negotiation.c
@@ -869,7 +869,8 @@ negotiate_stream_codecs (
   }
 
   /*
    * Check if there is a non-disabled codec left
    */
   for (item = new_codec_associations;
        item;
@@ -877,7 +878,7 @@ negotiate_stream_codecs (
   {
     CodecAssociation *ca = item->data;
 
-    if (!ca->disable && !ca->reserved && !ca->recv_only)
+    if (codec_association_is_valid_for_sending (ca))
       return new_codec_associations;
   }
 
@@ -869,7 +869,8 @@ negotiate_stream_codecs (
 
   /*
-   * Check if there is a non-disabled codec left
+   * Check if there is a non-disabled codec left that we can use
+   * for sending
    */
   for (item = new_codec_associations;
-- 
1.5.6.5




More information about the farsight-commits mailing list